##############################################################################
#
# Copyright (c) 2009 Zope Foundation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################
import os

from distutils.command.build import build as build_
from setuptools.command.develop import develop as develop_
from distutils.core import Command
from pythongettext.msgfmt import Msgfmt

class build(build_):

    sub_commands = build_.sub_commands[:]
    sub_commands.append(('van_build_i18n', None))


class develop(develop_):

    def install_for_development(self):
        ei = self.get_finalized_command("egg_info")
        sources = os.path.join(ei.egg_info, 'SOURCES.txt')
        sources = open(sources, 'r').read().splitlines()
        _compile_pofiles([s for s in sources if _is_pofile(s)])
        return develop_.install_for_development(self)


class van_build_i18n(Command):

    def initialize_options(self):
        pass

    def finalize_options(self):
        pass

    def run(self):
        build_py = self.get_finalized_command("build_py")
        sources = []
        for package, src_dir, build_dir, filenames in build_py.data_files:
            for filename in filenames:
                filename = os.path.join(build_dir, filename)
                if _is_pofile(filename):
                    sources.append(filename)
        _compile_pofiles(sources)

def _is_pofile(filename):
    if filename.endswith('.po') and os.path.exists(filename):
        # file may not exist if it has recently been deleted and
        # is still in SOURCES.txt
        return True
    return False

def _compile_pofiles(files):
    for src in files:
        dest = '%smo' % src[:-2]
        if not os.path.exists(dest):
            _compile(src, dest)
        else:
            src_mtime = os.stat(src)[8]
            dest_mtime = os.stat(dest)[8]
            if src_mtime > dest_mtime:
                _compile(src, dest)

def _compile(src, dest):
    print ('Compiling %s to %s' % (src, dest))
    f = open(dest, 'wb')
    try:
        f.write(Msgfmt(src).get())
    finally:
        f.close()



import os
from setuptools import setup, find_packages

long_description = (
    '.. contents::\n\n'
    + open(os.path.join('van', 'potomo', 'README.txt')).read()
    + '\n\n'
    + open(os.path.join('CHANGES.txt')).read()
    )


setup(name="van.potomo",
      version='2.0',
      license='ZPL 2.1',
      url='http://pypi.python.org/pypi/van.potomo',
      author_email='zope-dev@zope.org',
      packages=find_packages(),
      author="Vanguardistas LLC",
      description="PO to MO build time compiler",
      long_description=long_description,
      namespace_packages=["van"],
      install_requires = [
          'setuptools',
          'python-gettext'],
      classifiers=[
          'Intended Audience :: Developers',
          'License :: OSI Approved :: Zope Public License',
          'Framework :: Setuptools Plugin',
          'Programming Language :: Python',
          'Development Status :: 5 - Production/Stable',
          'Operating System :: OS Independent',
          'Topic :: Software Development :: Build Tools',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 2',
          ],

      entry_points = """
      [distutils.commands]
      van_build_i18n = van.potomo:van_build_i18n
      """,
      include_package_data = True,
      zip_safe = True,
      )
